--- linux-2.6.27.6/mm/vmalloc.c	2008-11-14 01:56:21.000000000 +0800
+++ linux-2.6.27.6.yaffs/mm/vmalloc.c	2011-05-08 18:02:40.000000000 +0800
@@ -616,6 +616,29 @@
 EXPORT_SYMBOL(vmalloc_user);
 
 /**
+ * vmalloc_user_uncached - allocate zeroed virtually contiguous memory for userspace
+ * @size: allocation size
+ *
+ * The resulting memory area is zeroed so it can be mapped to userspace
+ * without leaking data.
+ */
+void *vmalloc_user_uncached(unsigned long size)
+{
+	struct vm_struct *area;
+	void *ret;
+
+	ret = __vmalloc(size, GFP_KERNEL | __GFP_HIGHMEM | __GFP_ZERO, pgprot_noncached(PAGE_KERNEL));
+	if (ret) {
+		write_lock(&vmlist_lock);
+		area = __find_vm_area(ret);
+		area->flags |= VM_USERMAP;
+		write_unlock(&vmlist_lock);
+	}
+	return ret;
+}
+EXPORT_SYMBOL(vmalloc_user_uncached);
+
+/**
  *	vmalloc_node  -  allocate memory on a specific node
  *	@size:		allocation size
  *	@node:		numa node
